@@ -1,4 +1,4 @@
-__author__ = 'jaddison'
+__author__ = 'James Addison'
 
 import posixpath
 import datetime
